@@ -9,6 +9,8 @@ PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 logger = logging.getLogger('aug_sfutils.sfread')
 date_fmt = '%Y-%m-%d'
 logger.setLevel(logging.INFO)
+#logger.setLevel(logging.DEBUG)
+
 
 for key, val in sfdics.obj_name.items():
     exec('%s=%d' %(val, key))
@@ -278,8 +280,8 @@ class SFREAD:
         elif otyp == TimeBase:
             shape_arr = np.array([sfo.n_steps])
         elif otyp == AreaBase:
-            x = np.array([sfo.size_x, sfo.size_y, sfo.size_z, sfo.n_steps])
-            shape_arr = x[x != 0]
+            shape_arr = np.array([sfo.size_x + sfo.size_y + sfo.size_z, sfo.n_steps])
+            logger.debug('%d %d', *shape_arr)
         else:
             logger.error('Object %s is no signal, signalgroup, timebase nor areabase, skipping')
             return None
@@ -313,6 +315,7 @@ class SFREAD:
                     if nend is not None:
                         bytlen = (nend - nbeg)*np.prod(shape_arr[:-1])*type_len
                         shape_arr[-1] = nend - nbeg
+                print(bytlen, np.prod(shape_arr), type_len, addr)
                 data = np.ndarray(shape_arr, '>%s' %sfmt, self.getchunk(addr, bytlen), order='F')
 
 # LongLong in [ns] and no zero at TS06
@@ -597,7 +600,7 @@ class SFREAD:
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp != SignalGroup:
-            return None # Objects other than sig, sgr, tbase
+            return None
 
         for rel in sfo.relations:
             if self.sfh[rel].obj_type == TimeBase:
@@ -616,6 +619,12 @@ class SFREAD:
         by comparing with the size of the related TBase
         """
 
+        obj = str_byt.to_str(obj)
+        sfo = self.sfh[obj]
+        otyp = sfo.obj_type
+        if otyp != SignalGroup:
+            return False
+
         return (self.time_dim(obj) == 0)
 
 
@@ -627,5 +636,8 @@ class SFREAD:
 
         obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
+        otyp = sfo.obj_type
+        if otyp != SignalGroup:
+            return False
         
         return (self.time_dim(obj) == sfo.num_dims-1)
