@@ -7,6 +7,8 @@ from aug_sfutils import sfdics, str_byt
 
 logger = logging.getLogger('aug_sfutils.ww')
 logger.setLevel(logging.INFO)
+#logger.setLevel(logging.DEBUG)
+
 
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
 if not os.path.isfile(wwlib):
@@ -166,7 +168,7 @@ class WW:
             return {'items': items.value, 'format': format.value}
 
 
-    def SetObject(self, signame, data):
+    def SetObject(self, signame, data, tim_axis=0):
         """Stores 'data'-array of a given object named 'signame' of type 
         Signal, SigGroup or Areabase to the target shotfile
         """
@@ -180,7 +182,7 @@ class WW:
             elif otype == SignalGroup:
                 self.SetSignalGroup(signame, data)
             elif otype == AreaBase:
-                self.SetAreabase(signame, data)
+                self.SetAreabase(signame, data, tim_axis=tim_axis)
 
 
     def SetSignal(self, signame, data, indices=None):
@@ -298,7 +300,7 @@ class WW:
         return True
 
 
-    def SetAreabase(self, areaname, data, tim_axis=0):
+    def SetAreabase(self, areaname, data, sizes=None, tim_axis=0):
         """Stores 'data'-array of a given Areabase named 'areaname'
         to the target shotfile
         """
@@ -313,30 +315,42 @@ class WW:
 
             data = np.array(data, dtype=sfdics.fmt2np[dfmt])
             areaname = str_byt.to_byt(areaname)     
-            sizes = (ct.c_uint32 * 3)()
+            csizes = (ct.c_uint32 * 3)()
             if tim_axis is not None and tim_axis != 0:
                 logger.error('tim_axis can be only None or 0, not %d', tim_axis)
                 return
-            if tim_axis is None or data.ndim == 1:
+
+            if data.ndim > 2:
+                logger.error('AB %s hat %d dims: only a time and a space dependence are allowed, flatten the AB space-data', areaname, data.ndim)
+                return
+
+            if tim_axis is None:
                 nt = 1
+                if sizes is None:
+                    csizes[0] = data.shape[0]
+                else:
+                    nx = len(sizes)
+                    csizes[:nx] = sizes[:nx]
             else:
                 nt = data.shape[tim_axis]
-                jsiz = 0
-                for jdim in range(data.ndim):
-                    if jdim != tim_axis:
-                        sizes[jsiz] = data.shape[jdim]
-                    jsiz += 1
-            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *sizes[:3])
+                if sizes is None:
+                    csizes[:data.ndim-1] = np.delete(data.shape, tim_axis)[:data.ndim-1]
+                else:
+                    nx = len(sizes)
+                    csizes[:nx] = sizes[:nx]
+
+            logger.debug('AB %s, %d, %d, %d, %d, %d', areaname, sf_dtype, nt, *csizes)
+
             error  = ct.c_int32(0)
             name   = ct.c_char_p(areaname)
             lname  = ct.c_uint64(len(areaname))
-            k1     = ct.c_long(1)
-            k2     = ct.c_long(nt)
+            k1     = ct.c_uint32(1) # c_long
+            k2     = ct.c_uint32(nt)
             _k1    = ct.byref(k1)
             _k2    = ct.byref(k2)
             _type  = ct.byref(ct.c_uint32(sf_dtype))
             _error = ct.byref(error)
-            _sizes = ct.byref(sizes)
+            _sizes = ct.byref(csizes)
 
             libddww.wwainsert_(_error, self._diaref, name, _k1, _k2, _type, \
                                data.ctypes.data_as(ct.POINTER(ctyp)), \
